function [image, minim, max_scaled] = real2uint(image, qbit)
%REAL2UINT Convert double image to uint image.
%
%   Inputs:
%    image             - real image
%    qbit              - quantization bit for output image
%
%   Output:
%    image            - input image quantized at qbit
%    minim            - original minimum in real image
%    max_scaled       - maximum value in image after minimum subtraction
%
%If the input is already uint8 or uint16, it will be returned with no
%modifications, minim and max_scaled will be empty.
%
%-------------------------------------------------------------------------
% Copyright(c) 2019
% University of Cagliari
% Department of Electrical and Electronic Engineering
% Italy
% All Rights Reserved.
%-------------------------------------------------------------------------                                        
%                                                                      
% The University of Cagliari - Department of Electrical and Electronic
% Engineering hereby grants to ISO/IEC JTC1 SC29 WG1
% (JPEG Committee) and each Member of ISO/IEC JTC1 SC29 WG1 (JPEG
% Committee) who participate in the Working Group dedicated to the
% standardization of JPEG Pleno, a non-exclusive, nontransferable,  
% worldwide, license under "University of Cagliari - Department of
% Electrical and Electronic Engineering" copyrights
% in this software to reproduce, distribute, display, perform and 
% create derivative works for the sole and exclusive purposes of 
% creating a hologram reconstruction software in the frame of
% the JPEG Pleno standard.
%
% Modifications to this code shall be clearly indicated and      
% identified by the relevant copyright notice(s) of the party   
% generating these changes and/or derivative works.            
%   
% Nothing contained in this software shall, except as herein 
% expressly provided, be construed as conferring by implication,
% estoppel or otherwise, any license or right under (i) any existing
% or later issuing patent, whether or not the use of information in
% this software necessarily employs an invention of any existing or
% later issued patent, (ii) any copyright, (iii) any trademark, or
% (iv) any other intellectual property right.         
%           
% THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS "AS IS" AND
% ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
% TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
% PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE    
% COPYRIGHT OWNER BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
% SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
% LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
% USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED 
% AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT  
% LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING 
% IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
% THE POSSIBILITY OF SUCH DAMAGE.
%
%-------------------------------------------------------------------------

if isa(image, 'uint8') || isa (image, 'uint16')
    minim=[];
    max_scaled=[];
    return
end

minim=min(image(:));

image=(image-minim);

max_scaled=max(image(:));

image=(image/max_scaled);

image=image*( (2^(qbit))-1 );

if qbit<=8
    image=uint8(round(image));
else
    image=uint16(round(image));
end

end

