function info = getSettings(varargin)
    % Assembly of info struct for nrsh.m. For valid options see nrsh.m.
    %
    % Usage: info = getSettings('usagemode', 'individual', ...) etc. // Initialization
    %        info = getSettings(info, 'direction', 'forward', ...) etc. // Modification
    
    addpath(genpath('./core'));
    
    % Layman's check for octave compatible mode
    isOctave = false;
    try
      a = datetime; clear a;
      contains('abc', 'a');
      isOctave = false;
    catch me
      pkg load signal;
      isOctave = true;
    end
    
    % Valid field names
    validFieldnameList = {'usagemode', 'apertureinpxmode', 'ap_sizes', 'h_pos', 'v_pos', ...
                          'clip_min', 'clip_max', 'use_first_frame_reference', ...
                          'dataset', 'cfg_file', 'name_prefix', 'outfolderpath', ...
                          'direction', 'resize_fun', 'targetres', 'fps', ...
                          'wlen', 'pixel_pitch', 'method', 'apod', 'zero_pad', ...
                          'perc_clip', 'perc_value', 'hist_stretch', ...
                          'save_intensity', 'save_as_mat', 'save_as_image', ...
                          'show', 'bit_depth', 'reffronorm', 'offaxisfilter', ...
                          'ref_wave_rad', 'dc_filter_type', 'dc_filter_size', 'img_flt', ...
                          'shift_yx_r', 'shift_yx_g', 'shift_yx_b', ...
                          'hologramname', 'format', 'segmentsnum', ...
                          'segmentsres', 'subsegmentsres', 'spectrumscale'};
    printFieldnameList = [cell2mat(cellfun(@(x) [x, ', '], validFieldnameList(1:end-1), 'UniformOutput', false)), validFieldnameList{end}];

    
    if(isstruct(varargin{1}) && isfield(varargin{1}, 'isInfoStruct'))
        info = varargin{1};
        varargin(1) = [];
    else
        % Initialize info struct
        info = struct('isInfoStruct', 1);
        
        % Parse configuration file first, if existent
        fieldname = 'cfg_file';
        idx = find(cellfun(@(x) strcmpi(x, fieldname), varargin(1:2:end))==1, 1, 'first');
        if(idx)
            info.(fieldname) = varargin{2*idx};
            varargin(2*idx-1:2*idx) = [];

            %% Parse configuration file
            info = read_render_cfg(info);
            disp('Config file parsed.')
        end
    end
    
    if (mod(numel(varargin), 2))
        error('getSettings:input_args', 'Error in getSettings: Input should be paired up as "arg_name", "arg_value".')
    end
    
    % Parse remaining options, overwritting default options eventually
    for ii = 1:2:numel(varargin)
        fieldname = lower(varargin{ii});
        if((~isOctave && any(contains(validFieldnameList, fieldname))) || (isOctave && any(~cellfun('isempty', strfind(validFieldnameList, fieldname)))))
            info.(fieldname) = varargin{ii+1};
        else
            warning('getSettings:input_skipped', [fieldname ' is not a valid field name. Valid field names are: ' printFieldnameList])
        end
    end
end